/*
 * Copyright 2021 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.drools.workbench.screens.guided.dtable.backend.server.conversion.util;

public class CommaSeparatedListValueConverter {

    private final StringBuilder builder = new StringBuilder();
    private final char[] chars;

    boolean quoteOpen = false;
    boolean ignoreWhiteSpace = false;

    public CommaSeparatedListValueConverter(String value) {
        if (value.startsWith("\"")) {
            value = value.substring(1);
            quoteOpen = true;
        }
        if (value.endsWith("\"")) {
            value = value.substring(0, value.length() - 1);
        }
        chars = value.toCharArray();
    }

    public String convert() {
        builder.append("\'");

        for (char aChar : chars) {

            if (ignoreWhiteSpace && !Character.isWhitespace(aChar)) {
                ignoreWhiteSpace = false;
            }

            if (ignoreWhiteSpace && Character.isWhitespace(aChar)) {
                continue;
            } else if (aChar == '\"' && !quoteOpen) {
                quoteOpen = true;
            } else if (aChar == '\"' && quoteOpen) {
                quoteOpen = false;
            } else if (aChar == ',' && !quoteOpen) {
                builder.append("\', \'");
                ignoreWhiteSpace = true;
            } else if (aChar == '\'') {
                builder.append("\\\'");
            } else {
                builder.append(aChar);
            }
        }

        builder.append("\'");

        return builder.toString();
    }
}
